/*-----------------------------------------------------------------------
esurban_figures.do

Stata do file to replicate the figures of the article
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies

This requires esurban_table1.do, esurban_table2.do, 
and esurban_table4.do to be run before
-----------------------------------------------------------------------*/

* Initialise
clear all
set more off
set matsize 2000
quietly capture log close
log using ../../output/esurban_figures, text replace

* Set graphics format options
set scheme dpmono

* Define tempfiles
tempfile csize
tempfile mcvlpanel

* Prepare city size data and save
use ../../otherdata/ua_size, clear
gen ln_size = ln(size_pop10k)
keep ua_id ua_name ln_size size_pop10k
replace ua_name = "Cádiz" if ua_name == "Bahía de Cádiz"
replace ua_name = "Las Palmas" if ua_name == "Las Palmas de Gran Canaria"
replace ua_name = "Sta Cruz de Tenerife" if ua_name == "Santa Cruz de Tenerife - La Laguna"
replace ua_name = "Santander" if ua_name == "Santander - Torrelavega"
replace ua_name = "Castellón" if ua_name == "Castellón de la Plana"
replace ua_name = "Algeciras" if ua_name == "Bahía de Algeciras"
gen pos = 12
save "`csize'", replace

*************************************************************************
* Figure 1: Mean earnings and city size
*************************************************************************
* Read panel
use ../../output/mcvl_panel, clear
collapse (mean) avg_earnings=earnings, by (ua_id)
* Convert daily cents to anual euros
replace avg_earnings = avg_earnings*(30.5/100)*12
merge 1:1 ua_id using "`csize'"
drop _merge
* Regression line
gen ln_avg_earnings = ln(avg_earnings)
regress ln_avg_earnings ln_size
* Generate plot
twoway (scatter avg_earnings size_pop10k, sort xscale(log) yscale(log) mcolor(dknavy) msize(tiny) mlabel(ua_name) mlabsize(vsmall) mlabcolor(dknavy) mlabv(pos)), /*
*/ xsize(10) ysize(7) l2title("Mean annual earnings") l1title("(2004–2009 average in 2009 €, log scale)", size(small)) /*
*/ xtitle("City size") b2title("(people within 10km of average worker, log scale)", size(small)) /*
*/ xlabel(50000 125000 250000 500000 1000000 2000000, format(%12.0fc) labsize(small)) ylabel(16000 20000 24000 28000 32000, format(%12.0fc) labsize(small)) || /*
*/ function y=exp(_b[_cons]+_b[ln_size]*ln(x)), yscale(log) range(35000 2300000) n(2) lcolor(maroon) legend(off)
* Save plot
graph export "../../output/esurban_figure1.pdf", as(pdf) replace

*************************************************************************
* Figure 2: Static OLS estimation of the city-size premium
*************************************************************************
* Recover city premia from table 1 column (1)
use ../../output/esurban_table1_premia, clear
* Combine with log city size
merge 1:1 ua_id using "`csize'"
drop _merge
* Regression line
regress premium_pooled ln_size
local elast = string(_b[ln_size],"%9.4f")
* Generate plot
gen premium_plot = exp(premium_pooled)-1
twoway (scatter premium_plot size_pop10k, sort xscale(log) mcolor(dknavy) msize(tiny) mlabel(ua_name) mlabsize(vsmall) mlabcolor(dknavy) mlabv(pos)), /*
*/ xsize(10) ysize(7) l2title("Earnings premium," "static estimation, pooled OLS") /*
*/ xtitle("City size") b2title("(people within 10km of average worker, log scale)", size(small)) /*
*/ xlabel(50000 125000 250000 500000 1000000 2000000, format(%12.0fc) labsize(small)) ylabel(-0.1 "-10%" 0 "0%" 0.1 "10%" 0.2 "20%" 0.3 "30%" 0.4 "40%", labsize(small)) /*
*/ yscale(range(-0.1 0.4)) note("Elasticity: `elast'", ring(0) position(10) margin(medium)) /*
*/ yline(0, lwidth(thin) lpattern(dash) lcolor(gs8)) || /*
*/ function y=exp(_b[_cons]+_b[ln_size]*ln(x))-1, range(35000 2300000) n(2) lcolor(maroon) legend(off)
* Save plot
graph export "../../output/esurban_figure2.pdf", as(pdf) replace

*************************************************************************
* Figure 3: Earnings profiles relative to median-sized city
*************************************************************************
* Recover coefficients from table 2 column (1)
use "../../output/esurban_table2_coeff", clear
mkmat coeff, rownames(coeff_var)
matrix rename coeff b
foreach var in "ua_id_1" "ua_id_4" "ua_id_44" "uexp_1_2" "uexp_1_2_exp" "uexp_3_5" "uexp_3_5_exp" "experience" "experience2" "uexp_1_2_now5" "uexp_1_2_exp_now5" "uexp_3_5_now5" "uexp_3_5_exp_now5" "uexp_smaller_now5" "uexp_smaller_exp_now5" {
  local b_`var' = el(matrix(b),rownumb(matrix(b),"`var'"),1)
}
matrix drop b
* Generate plot
local drop_MAD = exp(`b_ua_id_1'+(`b_uexp_1_2')*(5)+(`b_uexp_1_2_exp')*(5^2)+(`b_uexp_1_2_now5')*(5)+(`b_uexp_1_2_exp_now5')*(5^2)-(`b_ua_id_44'))-1
local drop_SVQ = exp(`b_ua_id_4'+(`b_uexp_3_5')*(5)+(`b_uexp_3_5_exp')*(5^2)+(`b_uexp_3_5_now5')*(5)+(`b_uexp_3_5_exp_now5')*(5^2)-(`b_ua_id_44'))-1
twoway (function y=exp(`b_ua_id_1'+(`b_uexp_1_2')*(x)+(`b_uexp_1_2_exp')*(x^2)+(`b_uexp_1_2_now5')*(x)+(`b_uexp_1_2_exp_now5')*(x^2)-(`b_ua_id_44'))-1, range(0 10) lcolor(red) lwidth(medthick)) /*
*/     (function y=exp((`b_uexp_1_2')*(5)+(`b_uexp_1_2_exp')*(5)*(x))-1, range(5 10) base(`drop_MAD') dropline(5) lcolor(red) lpattern(dash) lwidth(medthick)) /*
*/     (function y=exp(`b_ua_id_4'+(`b_uexp_3_5')*(x)+(`b_uexp_3_5_exp')*(x^2)+(`b_uexp_3_5_now5')*(x)+(`b_uexp_3_5_exp_now5')*(x^2)-(`b_ua_id_44'))-1, range(0 10) lcolor(navy) lwidth(medthick)) /*
*/     (function y=exp((`b_uexp_3_5')*(5)+(`b_uexp_3_5_exp')*(5)*(x))-1, range(5 10) base(`drop_SVQ') dropline(5) lcolor(navy) lpattern(dash) lwidth(medthick) /*
*/ xsize(10) ysize(7) ytitle("") l2title("Earnings premium," "relative to Santiago - median size") /*
*/ xtitle("Years worked", margin(medium)) ylabel(0 "0%" 0.05 "5%" 0.1 "10%" 0.15 "15%" 0.2 "20%" 0.25 "25%" 0.3 "30%" 0.35 "35%" 0.4 "40%",labsize(small)) xlabel(0(1)10, format(%12.0fc) labsize(small)) plotr(m(zero)) legend(off))
* Save plo
graph export "../../output/esurban_figure3a.pdf", as(pdf) replace

* Recover coefficients from table 1 column (3)
use "../../output/esurban_table1_coeff", clear
mkmat coeff_fe, rownames(coeff_var)
matrix rename coeff_fe b
foreach var in "ua_id_1" "ua_id_4" "ua_id_44" {
  local b_`var' = el(matrix(b),rownumb(matrix(b),"`var'"),1)
}
matrix drop b
* Generate plot
local drop_MAD = exp(`b_ua_id_1' - `b_ua_id_44')-1
local drop_SVQ = exp(`b_ua_id_4' - `b_ua_id_44')-1
twoway (function y=`drop_MAD', range(0 10) lcolor(red) lwidth(medthick)) /*
*/ (function y=0, range(5 10) base(`drop_MAD') dropline(5) lcolor(red) lpattern(dash) lwidth(medthick)) /*
*/ (function y=`drop_SVQ', range(0 10) lcolor(navy) lwidth(medthick)) /*
*/ (function y=0, range(5 10) base(`drop_SVQ') dropline(5) lcolor(navy) lpattern(dash) lwidth(medthick) /*
*/ xsize(10) ysize(7) ytitle("") l2title("Earnings premium," "relative to Santiago - median size") /*
*/ xtitle("Years worked", margin(medium)) ylabel(0 "0%" 0.05 "5%" 0.1 "10%" 0.15 "15%" 0.2 "20%" 0.25 "25%" 0.3 "30%" 0.35 "35%" 0.4 "40%",labsize(small)) xlabel(0(1)10, format(%12.0fc) labsize(small)) plotr(m(zero)) legend(off))
* Save plot
graph export "../../output/esurban_figure3b.pdf", as(pdf) replace

*************************************************************************
* Figure 4: Earnings profiles relative to median-sized city, worker with and without prior experience
*************************************************************************
* Recover coefficients from table 2 column (1)
use "../../output/esurban_table2_coeff", clear
mkmat coeff, rownames(coeff_var)
matrix rename coeff b
foreach var in "ua_id_1" "ua_id_4" "ua_id_44" "uexp_1_2" "uexp_1_2_exp" "uexp_3_5" "uexp_3_5_exp" "experience" "experience2" "uexp_1_2_now5" "uexp_1_2_exp_now5" "uexp_3_5_now5" "uexp_3_5_exp_now5" "uexp_smaller_now5" "uexp_smaller_exp_now5" {
  local b_`var' = el(matrix(b),rownumb(matrix(b),"`var'"),1)
}
matrix drop b
* Generate plot
local pe1 "0"
local pe2 "5"
twoway (function y=exp(`b_ua_id_1'+(`b_uexp_smaller_now5')*(`pe1')+(`b_uexp_smaller_exp_now5')*(`pe1')*(`pe1'+x)+(`b_uexp_1_2')*(x)+(`b_uexp_1_2_exp')*(x)*(`pe1'+x)+(`b_uexp_1_2_now5')*(x)+(`b_uexp_1_2_exp_now5')*(x)*(`pe1'+x)-(`b_ua_id_44'))-1, range(0 10) lcolor(red) lwidth(medthick)) /*
*/     (function y=exp(`b_ua_id_1'+(`b_uexp_smaller_now5')*(`pe2')+(`b_uexp_smaller_exp_now5')*(`pe2')*(`pe2'+x)+(`b_uexp_1_2')*(x)+(`b_uexp_1_2_exp')*(x)*(`pe2'+x)+(`b_uexp_1_2_now5')*(x)+(`b_uexp_1_2_exp_now5')*(x)*(`pe2'+x)-(`b_ua_id_44'))-1, range(0 10) lcolor(red) lwidth(medthick) lpattern(dash)) /*
*/     (function y=exp(`b_ua_id_4'+(`b_uexp_smaller_now5')*(`pe1')+(`b_uexp_smaller_exp_now5')*(`pe1')*(`pe1'+x)+(`b_uexp_3_5')*(x)+(`b_uexp_3_5_exp')*(x)*(`pe1'+x)+(`b_uexp_3_5_now5')*(x)+(`b_uexp_3_5_exp_now5')*(x)*(`pe1'+x)-(`b_ua_id_44'))-1, range(0 10) lcolor(navy) lwidth(medthick)) /*
*/     (function y=exp(`b_ua_id_4'+(`b_uexp_smaller_now5')*(`pe2')+(`b_uexp_smaller_exp_now5')*(`pe2')*(`pe2'+x)+(`b_uexp_3_5')*(x)+(`b_uexp_3_5_exp')*(x)*(`pe2'+x)+(`b_uexp_3_5_now5')*(x)+(`b_uexp_3_5_exp_now5')*(x)*(`pe2'+x)-(`b_ua_id_44'))-1, range(0 10) lcolor(navy) lwidth(medthick) lpattern(dash) /*
*/ xsize(10) ysize(7) ytitle("") l2title("Earnings premium," "relative to Santiago - median size") /*
*/ xtitle("Years relative to migration date", margin(medium)) ylabel(0 "0%" 0.05 "5%" 0.1 "10%" 0.15 "15%" 0.2 "20%" 0.25 "25%" 0.3 "30%" 0.35 "35%" 0.4 "40%",labsize(small)) xlabel(0(1)10, format(%12.0fc) labsize(small)) plotr(m(zero)) legend(off))
* Save plot
graph export "../../output/esurban_figure4.pdf", as(pdf) replace

*************************************************************************
* Figure 5: Dynamic fixed-effects estimation of the medium-term city-size premium
*************************************************************************
* Recover city premia from table 2 column (1)
use ../../output/esurban_table2_premia, clear
* Combine with log city size
merge 1:1 ua_id using "`csize'"
drop _merge
* Regression line
regress premium_medterm ln_size
local elast = string(_b[ln_size],"%9.4f")
* Generate plot
gen premium_plot = exp(premium_medterm)-1
twoway (scatter premium_plot size_pop10k, sort xscale(log) mcolor(dknavy) msize(tiny) mlabel(ua_name) mlabsize(vsmall) mlabcolor(dknavy) mlabv(pos)), /*
*/ xsize(10) ysize(7) l2title("Medium-term earnings premium," "dynamic estimation, fixed-effects") /*
*/ xtitle("City size") b2title("(people within 10km of average worker, log scale)", size(small)) /*
*/ xlabel(50000 125000 250000 500000 1000000 2000000, format(%12.0fc) labsize(small)) ylabel(-0.1 "-10%" 0 "0%" 0.1 "10%" 0.2 "20%" 0.3 "30%" 0.4 "40%", labsize(small)) /*
*/ yscale(range(-0.1 0.4)) note("Elasticity: `elast'", ring(0) position(10) margin(medium)) /*
*/ yline(0, lwidth(thin) lpattern(dash) lcolor(gs8)) || /*
*/ function y=exp(_b[_cons]+_b[ln_size]*ln(x))-1, range(35000 2300000) n(2) lcolor(maroon) legend(off)
* Save plot
graph export "../../output/esurban_figure5.pdf", as(pdf) replace

*************************************************************************
* Figure 6: Non-parametric pre- and post-migration earnings profile relative to median-sized city
*************************************************************************
* Read panel
use ../../output/mcvl_panel, clear
* Generate extra variables
gen ln_earnings = ln(earnings)
gen experience2 = experience^2
gen tenure2 = tenure^2
gen uexp_1_2_exp = uexp_1_2 * experience
gen uexp_3_5_exp = uexp_3_5 * experience
gen uexp_1_2_now5 = uexp_1_2 * ua_1_5
gen uexp_1_2_exp_now5 = uexp_1_2_exp * ua_1_5
gen uexp_3_5_now5 = uexp_3_5 * ua_1_5
gen uexp_3_5_exp_now5 = uexp_3_5_exp * ua_1_5
gen uexp_smaller_now5 = uexp_smaller * ua_1_5
gen uexp_smaller_exp_now5 = uexp_smaller * experience * ua_1_5
* Drop migrants with multiple moves
egen num_mig = sum(migrant_arrive), by (person_id)
drop if num_mig > 1
* Identify time of migration
gen date_m = date if migrant_arrive == 1
egen date_mig = min(date_m), by (person_id)
gen seq_mig = date - date_mig
drop num_mig date_m
* Create quarters before and after migration
gen qt_mig = .
* Quarter-by-quarter indicators within two years of migration date
replace qt_mig = floor(seq_mig / 3) if seq_mig >= 0 & seq_mig < 24
replace qt_mig = ceil((seq_mig +1 ) / 3) - 1 if seq_mig < 0 & seq_mig > -25
* Annual indicator for three years from migration date
replace qt_mig =  8 if seq_mig >=  24 & !missing(seq_mig)
replace qt_mig = -9 if seq_mig <= -25
replace qt_mig = 99 if missing(qt_mig)
xi i.qt_mig, noomit
renpfix _I
drop qt_mig_19
* Table 2 column (1) controls
local controls_a "uexp_1_2 uexp_1_2_exp uexp_3_5 uexp_3_5_exp experience experience2 uexp_1_2_now5 uexp_1_2_exp_now5 uexp_3_5_now5 uexp_3_5_exp_now5 uexp_smaller_now5 uexp_smaller_exp_now5 tenure tenure2 skill_1 skill_2 skill_3 skill_4"
local controls_b "contract_fixedterm contract_parttime date_2 - date_72 sector2d_16 - sector2d_95"
* Additional controls for quarter relative to migration date
local ashdip_controls "qt_mig_1 - qt_mig_8 qt_mig_10 - qt_mig_18"
* Estimate table 2 column (1) with time-from-migration controls
xtset person_id date
xtreg ln_earnings ua_id_1 - ua_id_82 `controls_a' `controls_b' `ashdip_controls', fe cluster(person_id)
* Create data to be plotted
clear
set obs 25
gen qt = _n - 13
gen yr = qt / 4
local pe "5"
gen rel_wage = .
replace rel_wage = exp(_b[qt_mig_1])-1 if qt <= -9
forvalues q = -8(1)-2 {
  local qtcoeff = `q' + 10
  replace rel_wage = exp(_b[qt_mig_`qtcoeff'])-1 if qt == `q'   
}
replace rel_wage = 0 if qt == -1
forvalues q = 0(1)7 {
  local qtcoeff = `q' + 10
  replace rel_wage = exp(_b[qt_mig_`qtcoeff']+_b[ua_id_1]+_b[uexp_smaller_now5]*(`pe')+_b[uexp_smaller_exp_now5]*(`pe')*(`pe'+yr)+_b[uexp_1_2]*(yr)+_b[uexp_1_2_exp]*(yr)*(`pe'+yr)+_b[uexp_1_2_now5]*(yr)+_b[uexp_1_2_exp_now5]*(yr)*(`pe'+yr)-_b[ua_id_44])-1 if qt == `q'   
}
replace rel_wage = exp(_b[qt_mig_18]+_b[ua_id_1]+_b[uexp_smaller_now5]*(`pe')+_b[uexp_smaller_exp_now5]*(`pe')*(`pe'+yr)+_b[uexp_1_2]*(yr)+_b[uexp_1_2_exp]*(yr)*(`pe'+yr)+_b[uexp_1_2_now5]*(yr)+_b[uexp_1_2_exp_now5]*(yr)*(`pe'+yr)-_b[ua_id_44])-1 if qt >= 8
set obs 26
replace yr = -0.0001 if missing(yr)
sort yr
replace rel_wage = rel_wage[_n-1] if missing(rel_wage)
* Generate plot
twoway (line rel_wage yr, sort lcolor(red) lwidth(medthick) /*
*/ xsize(10) ysize(7) ytitle("") l2title("Earnings premium," "relative to Santiago - median size") /*
*/ xtitle("Years relative to migration date", margin(medium)) ylabel(-0.05 "-5%" 0 "0%" 0.05 "5%" 0.1 "10%" 0.15 "15%" 0.2 "20%" 0.25 "25%" 0.3 "30%" 0.35 "35%",labsize(small)) xlabel(-3(1)3, format(%12.0fc) labsize(small)) plotr(m(zero)) legend(off))
* Save plot
graph export "../../output/esurban_figure6.pdf", as(pdf) replace

*************************************************************************
* Figure 7: Earnings profiles relative to median-sized city, high- and low-ability worker
*************************************************************************
* Recover coefficients from table 4 column (1)
use "../../output/esurban_table4_coeff", clear
mkmat boot0, rownames(coeff_var)
matrix rename boot0 b
foreach var in "ua_id_1" "ua_id_4" "ua_id_44" "fe_uexp_1_2" "fe_uexp_1_2_exp" "fe_uexp_3_5" "fe_uexp_3_5_exp" "fe_exp" "fe_exp2" "uexp_1_2" "uexp_1_2_exp" "uexp_3_5" "uexp_3_5_exp" "experience" "experience2" "uexp_1_2_now5" "uexp_1_2_exp_now5" "uexp_3_5_now5" "uexp_3_5_exp_now5" "uexp_smaller_now5" "uexp_smaller_exp_now5" {
  local b_`var' = el(matrix(b),rownumb(matrix(b),"`var'"),1)
}
matrix drop b
* Recover worker fixed-effects from table 4 column (1)
use "../../output/esurban_table6_fe_row1", clear
keep if order_id == 0
centile fe, centile(25 75)
local fe_p25 = r(c_1)
local fe_p75 = r(c_2)
* Generate plot
local drop_MAD = exp(`b_ua_id_1' - `b_ua_id_44')-1
local drop_SVQ = exp(`b_ua_id_4' - `b_ua_id_44')-1
twoway (function y=exp(`b_ua_id_1'+(`b_uexp_1_2')*(x)+(`b_uexp_1_2_exp')*(x^2)+(`b_uexp_1_2_now5')*(x)+(`b_uexp_1_2_exp_now5')*(x^2)+(`fe_p75')*(`b_fe_uexp_1_2')*(x)+(`fe_p75')*(`b_fe_uexp_1_2_exp')*(x^2)-(`b_ua_id_44'))-1, range(0 10) lcolor(red) lwidth(medthick)) /*
*/     (function y=exp(`b_ua_id_1'+(`b_uexp_1_2')*(x)+(`b_uexp_1_2_exp')*(x^2)+(`b_uexp_1_2_now5')*(x)+(`b_uexp_1_2_exp_now5')*(x^2)+(`fe_p25')*(`b_fe_uexp_1_2')*(x)+(`fe_p25')*(`b_fe_uexp_1_2_exp')*(x^2)-(`b_ua_id_44'))-1, range(0 10) lcolor(red) lwidth(medthick) lpattern(dash)) /*
*/     (function y=exp(`b_ua_id_4'+(`b_uexp_3_5')*(x)+(`b_uexp_3_5_exp')*(x^2)+(`b_uexp_3_5_now5')*(x)+(`b_uexp_3_5_exp_now5')*(x^2)+(`fe_p75')*(`b_fe_uexp_3_5')*(x)+(`fe_p75')*(`b_fe_uexp_3_5_exp')*(x^2)-(`b_ua_id_44'))-1, range(0 10) lcolor(navy) lwidth(medthick)) /*
*/     (function y=exp(`b_ua_id_4'+(`b_uexp_3_5')*(x)+(`b_uexp_3_5_exp')*(x^2)+(`b_uexp_3_5_now5')*(x)+(`b_uexp_3_5_exp_now5')*(x^2)+(`fe_p25')*(`b_fe_uexp_3_5')*(x)+(`fe_p25')*(`b_fe_uexp_3_5_exp')*(x^2)-(`b_ua_id_44'))-1, range(0 10) lcolor(navy) lwidth(medthick) lpattern(dash) /*
*/ xsize(10) ysize(7) ytitle("") l2title("Earnings premium," "relative to Santiago - median size") /*
*/ xtitle("Years worked", margin(medium)) ylabel(0 "0%" 0.05 "5%" 0.1 "10%" 0.15 "15%" 0.2 "20%" 0.25 "25%" 0.3 "30%" 0.35 "35%" 0.4 "40%",labsize(small)) xlabel(0(1)10, format(%12.0fc) labsize(small)) plotr(m(zero)) legend(off))
* Save plot
graph export "../../output/esurban_figure7.pdf", as(pdf) replace

*************************************************************************
* Figure 8: Comparisons of worker fixed-effects distributions across cities
*************************************************************************
* Plot distributions of worker fixed-effects
local panels = "a b c"
forvalues rowi = 1(1)3 {
  local panel `: word `rowi' of `panels''
  use "../../output/esurban_table6_fe_row`rowi'", clear
  keep if order_id == 0
  keep if cat == 1 | cat == 2
  sort cat
  by cat: egen pbot=pctile(fe), p(0.2)
  by cat: egen ptop=pctile(fe), p(99.8)
  keep if pbot<=fe & fe<=ptop
  drop pbot ptop
  egen mean_sm = mean(fe) if cat == 1
  egen mean_small = mean(mean_sm)
  gen fe_norm = fe - mean_small
  twoway (kdensity fe_norm if cat == 1, bwidth(0.1) lcolor(navy) lwidth(medthick) lpattern(dash)) || (kdensity fe_norm if cat == 2, bwidth(0.1) lcolor(red) lwidth(medthick)), /*
*/  xsize(10) ysize(7) yscale(range(0 1.1)) xscale(range(-1.5 1.5)) ytitle("") l2title("Densities") xtitle("Worker fixed-effects", margin(tiny)) /*
*/  ylabel(0(0.25)1.25, format(%3.2f) labsize(small) glcolor(white)) xlabel(-1(1)1, labsize(small)) graphregion(fcolor(white) lcolor(white) ilcolor(white)) /*
*/  plotregion(fcolor(white) lcolor(white) ilcolor(white)) legend(on lab(1 "Smaller cities") lab (2 "5 biggest cities") position(3) ring(0) col(1) region(lcolor(white) margin(zero)))
  graph export "../../output/esurban_figure8`panel'.pdf", as(pdf) replace
}
* Plot distributions of log earnings
use "../../output/esurban_table6_w", clear
keep if order_id == 0
keep if cat == 1 | cat == 2
sort cat
by cat: egen pbot=pctile(w), p(0.2)
by cat: egen ptop=pctile(w), p(99.8)
keep if pbot<=w & w<=ptop
drop pbot ptop
egen mean_sm = mean(w) if cat == 1
egen mean_small = mean(mean_sm)
gen w_norm = w - mean_small
twoway (kdensity w_norm if cat == 1, bwidth(0.1) lcolor(navy) lwidth(medthick) lpattern(dash)) || (kdensity w_norm if cat == 2, bwidth(0.1) lcolor(red) lwidth(medthick)), /*
*/  xsize(10) ysize(7) yscale(range(0 1.1)) xscale(range(-1.5 1.5)) ytitle("") l2title("Densities") xtitle("Log earnings", margin(tiny)) /*
*/  ylabel(0(0.25)1.25, format(%3.2f) labsize(small) glcolor(white)) xlabel(-1(1)1, labsize(small)) graphregion(fcolor(white) lcolor(white) ilcolor(white)) /*
*/  plotregion(fcolor(white) lcolor(white) ilcolor(white)) legend(on lab(1 "Smaller cities") lab (2 "5 biggest cities") position(3) ring(0) col(1) region(lcolor(white) margin(zero)))
graph export "../../output/esurban_figure8d.pdf", as(pdf) replace

log close

