/*-----------------------------------------------------------------------
mcvl_merge_cohorts_tax.do

Stata do file used to recreate the panel for
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies

Merges MCVL cohorts with tax earnings and creates real daily earnings
-----------------------------------------------------------------------*/

** Merge MCVL 2013 cohort data sets with MCVL additional waves (those individuals not present in 2013)

* Reduce cohort size to only relevant observations
forval num = 1962/1991 {
  use "../../tmp/cohort_`num'", clear
  * Keep years for estimation
  drop if year < 2004 | year > 2009
  * Keeping individuals between 18 and 47
  gen age = year - int(birth_date / 100)
  drop if age < 18 | age > 47
  * Dropping non-working episodes
  drop if days_worked_month == .
  * Dropping irrelevant variables
  drop age
  * Making education numeric
  destring edu_code, replace
  save "../../tmp/coh_`num'", replace
}

* Same prodcedure for additional MCVL waves
forval num = 2005/2012 {
  use "../../tmp/additional_`num'", clear
  * Keep years for estimation
  drop if year < 2004 | year > 2009
  * Drop individuals who were born before 1962 (see above)
  drop if birth_date < 196200
  * Drop individuals who were born after 1991 (see above)
  drop if birth_date > 199200
  * Keeping individuals between 18 and 47
  gen age = year - int(birth_date / 100)
  drop if age < 18 | age > 47
  * Dropping non-working episodes
  drop if days_worked_month == .
  * Dropping irrelevant variables
  drop age
  * Making education numeric
  destring edu_code, replace
  save "../../tmp/add_`num'", replace
}

* Append all temporary data sets
use "../../tmp/coh_1962", clear
forval num = 1963/1991 {
  append using "../../tmp/coh_`num'"
}
forval num = 2005/2012 {
  append using "../../tmp/add_`num'"
}

** Merge MCVL with establishment-year standardized sector CNAE93
merge m:1 firm_id_sec year using "../../tmp/firm_cnae93"
drop if _merge == 2
replace sector = sector_year if sector != sector_year & sector_year != .
drop sector_year _merge

** Combine MCVL and tax data sets
merge m:1 person_id year firm_id_tax using "../../tmp/tax_all", keepusing(earnings)
drop if _merge == 2
rename _merge merge_mcvltax
rename earnings earnings_year_firm_tax
* Deflate capped social security earnings (tax earnings already delated in mcvl_merge_tax.do)
merge m:1 year using "../../otherdata/cpi_annual", keepusing(cpi_index2009)
drop if _merge == 2
replace earnings_capped_ss = earnings_capped_ss / cpi_index2009
drop cpi_index2009 _merge
* Compute ratio of tax to social security earnings in the year 
sort person_id year month 
egen days_year_firm = sum(days_worked_month) if merge_mcvltax == 3, by (person_id year firm_id_tax)
egen earnings_year_firm_ss = sum(earnings_capped_ss) if merge_mcvltax == 3, by (person_id year firm_id_tax)
egen min_earnings_firm = min(earnings_capped_ss) if merge_mcvltax == 3, by (person_id year firm_id_tax)
gen ratio = earnings_year_firm_tax / earnings_year_firm_ss
* Daily earnings (annual tax earnings in the firm allocated across months in the firm in proportion to social security earnings)
gen earnings = earnings_capped_ss * ratio / days_worked_month if min_earnings_firm >= 0
replace earnings = earnings_year_firm_tax / days_year_firm if min_earnings_firm < 0
replace earnings_capped_ss = earnings_capped_ss / days_worked_month
drop earnings_year_firm_tax days_year_firm earnings_year_firm_ss min_earnings_firm ratio 

* Province
gen prov_id = int(muni_id / 1000)

* Ordering and labeling variables
order person_id - left_1_5 earnings earnings_capped_ss - ptcoef job_relationship prov_id muni_id sector firm_id_tax merge_mcvltax
label var earnings "Total real daily earnings from tax returns (in 2009 cents of euro)"
label var earnings_capped_ss "Top- and bottom-coded real daily earnings from social security records (in 2009 cents of euro)" 
label var prov_id "Firm province"
label var merge_mcvltax "Merge between MCVL and tax data"
compress

* Save entire panel
save "../../tmp/mcvl_tax", replace

* Erase all temporary data sets
foreach num of numlist 1962/1991 {
  erase "../../tmp/coh_`num'.dta"
}
foreach num of numlist 1962/1995 {
  erase "../../tmp/cohort_`num'.dta"
}
foreach num of numlist 2005/2012 {
  erase "../../tmp/additional_`num'.dta"
  erase "../../tmp/add_`num'.dta"
}
erase "../../tmp/mcvl_cdf_2013/affiliates_4.dta"
foreach num of numlist 2004/2013 {
  erase "../../tmp/mcvl_cdf_`num'/affiliates_1.dta"
  erase "../../tmp/mcvl_cdf_`num'/affiliates_2.dta"
  erase "../../tmp/mcvl_cdf_`num'/affiliates_3.dta"
  erase "../../tmp/mcvl_cdf_`num'/contribution_10.dta"
  erase "../../tmp/mcvl_cdf_`num'/contribution_11.dta"
  erase "../../tmp/mcvl_cdf_`num'/contribution_12.dta"
  erase "../../tmp/mcvl_cdf_`num'/contribution_13.dta"
  erase "../../tmp/mcvl_cdf_`num'/contribution_1.dta"
  erase "../../tmp/mcvl_cdf_`num'/contribution_2.dta"
  erase "../../tmp/mcvl_cdf_`num'/contribution_3.dta"
  erase "../../tmp/mcvl_cdf_`num'/contribution_4.dta"
  erase "../../tmp/mcvl_cdf_`num'/contribution_5.dta"
  erase "../../tmp/mcvl_cdf_`num'/contribution_6.dta"
  erase "../../tmp/mcvl_cdf_`num'/contribution_7.dta"
  erase "../../tmp/mcvl_cdf_`num'/contribution_8.dta"
  erase "../../tmp/mcvl_cdf_`num'/contribution_9.dta"
  erase "../../tmp/mcvl_cdf_`num'/individuals.dta"
  erase "../../tmp/mcvl_cdf_`num'/tax.dta"
  rmdir "../../tmp/mcvl_cdf_`num'"
}
erase "../../tmp/firm_cnae93.dta"
erase "../../tmp/tax_all.dta"
