/*-----------------------------------------------------------------------
mcvl_panel.do

Stata do file used to recreate the panel for
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies

Prepares final panel for estimations after applying sample restrictions
-----------------------------------------------------------------------*/

** Drop all non-relevant observations
use "../../tmp/mcvl_tax", clear
* Women
drop if sex == 2
* Observations where MCVL and fiscal data do not match (self-employed, unemployed, Basque Country and Navarre, and special regimes without fiscal data)
drop if merge_mcvltax != 3
drop merge_mcvltax
* Only urban areas
drop if missing(ua_id)
* Basque Country and Navarre
drop if muni_id >=  1000 & muni_id <  2000
drop if muni_id >= 20000 & muni_id < 21000
drop if muni_id >= 31000 & muni_id < 32000
drop if muni_id >= 48000 & muni_id < 49000
* Ceuta and Melilla
drop if muni_id == 51001 | muni_id == 52001
* Unemployed
drop if job_relationship > 749 & job_relationship < 760
* Public employees
drop if job_relationship >= 900 & job_relationship <= 932
* Peculiar job relationships (e.g. apprenticeship status, co-op workers)
drop if job_relationship == 87 | job_relationship == 400 | job_relationship == 500 | job_relationship > 932
drop job_relationship
* Non-contribution occupational categories
drop if occupation < 1 | occupation > 10
* Non general SS regime
drop if regime != 111
* Foreign born
keep if birth_country == "N00" & birth_prov >= 1 & birth_prov <= 52
* Foreign nationals
drop if nationality != "N00" & nationality != ""
* Agriculture, forestry and fishing sectors
drop if sector < 100
* Extractive activities
drop if sector < 150
* Public administration, education and health services
drop if sector > 750 & sector < 900
* International organizations sectors
drop if sector == 990
* No-contract status
drop if contract < 100
* Workers whose contracts stipulate discontinuous involvement
drop if contract >= 300 & contract < 400

** Adjust for part-time coefficient and number of days worked in calendar year
* Full time coded as 0
replace ptcoef = 1000 if ptcoef == 0
* set to full time if full-time contract type
replace ptcoef = 1000 if contract_type >= 100 & contract_type < 200
replace ptcoef = 1000 if contract_type >= 400 & contract_type < 500
* Keep those who worked at least the equivalent of 30 days full-time in calendar year
gen daysequiv = days_worked_month * ptcoef
egen yeardays = sum (daysequiv), by (person_id year)
drop if yeardays <= 31000
drop daysequiv yeardays
* Keep those with available earnings data
drop if earnings == . | earnings == 0
* Adjust real daily earnings by part-time work
replace earnings = earnings / ptcoef * 1000

** Construct and adjust remaining explanatory variables
* Education categories
* set coding errors to missing
replace edu_code = . if (edu_code >  0 & edu_code < 10) | (edu_code > 11 & edu_code < 20)
replace edu_code = . if (edu_code > 22 & edu_code < 30) | (edu_code > 32 & edu_code < 40) | edu_code > 48
* less than secondary education
gen edu_belowsecondary = .
replace edu_belowsecondary = 1 if edu_code <= 32
replace edu_belowsecondary = 0 if edu_code > 32 & !missing(edu_code)
* secondary education
gen edu_secondary = .
replace edu_secondary = 1 if edu_code >= 40 & edu_code  <= 43
replace edu_secondary = 0 if (edu_code >= 44 & !missing(edu_code)) | edu_belowsecondary == 1
* tertiary education
gen edu_tertiary = .
replace edu_tertiary = 1 if edu_code >= 44 & !missing(edu_code)
replace edu_tertiary = 0 if edu_belowsecondary == 1 | edu_secondary == 1
drop if edu_code == .
* Specify firm tenure and experience variables in years
gen age = (year + month/12) - (int(birth_date/100) + (birth_date - 100*int(birth_date/100))/12)
foreach var of varlist exp tenure uexp_1_2 - left_1_5 {
  replace `var' = `var' / 365
}
* Contract types
gen contract_parttime = 1
replace contract_parttime = 0 if contract_type >= 100 & contract_type < 200
replace contract_parttime = 0 if contract_type >= 400 & contract_type < 500
gen contract_fixedterm = 0
replace contract_fixedterm = 1 if contract_type > 400
drop regime contract_type ptcoef

** Constructing all types of dummies
* Year-month dummies
gen date = (year - 2004) * 12 + month
xi i.date, noomit
rename _I* *
* Skill dummies
gen skill = .
replace skill = 1 if occupation == 1
replace skill = 2 if occupation == 2 | occupation == 3
replace skill = 3 if occupation == 4 | occupation == 5 | occupation == 6
replace skill = 4 if occupation == 7 | occupation == 8 | occupation == 9
replace skill = 5 if occupation == 10
xi i.skill, noomit
rename _I* *
* Urban area size dummies
gen ua_1_2 = 1 if ua_id == 1 | ua_id == 2
replace ua_1_2 = 0 if ua_1_2 == .
gen ua_3_5 = 1 if ua_id == 3 | ua_id == 4 | ua_id == 8
replace ua_3_5 = 0 if ua_3_5 == .
gen ua_1_5 = 1 if ua_id == 1 | ua_id == 2 | ua_id == 3 | ua_id == 4 | ua_id == 8
replace ua_1_5 = 0 if ua_1_5 == .
gen ua_smaller = 0
replace ua_smaller = 1 if !missing(ua_id) & ua_1_5 != 1
* Urban area dummies
xi i.ua_id, noomit
rename _I* *
* 2-digit sector dummies
gen sector2d = .
replace sector2d = 1 if sector == 0 | sector == 1 | (sector >=  11 & sector <= 15)
replace sector2d = 2 if sector == 20
replace sector2d = 5 if sector == 50
replace sector2d = 10 if sector == 10 | (sector >= 101 & sector <= 103)
replace sector2d = 11 if sector >= 111 & sector <= 112
replace sector2d = 12 if sector == 112
replace sector2d = 13 if sector >= 131 & sector <= 132 
replace sector2d = 14 if sector >= 141 & sector <= 145 
replace sector2d = 15 if sector >= 151 & sector <= 159
replace sector2d = 16 if sector == 160
replace sector2d = 17 if sector >= 171 & sector <= 177
replace sector2d = 18 if sector >= 181 & sector <= 183
replace sector2d = 19 if sector >= 191 & sector <= 193
replace sector2d = 20 if sector >= 201 & sector <= 205
replace sector2d = 21 if sector >= 211 & sector <= 212
replace sector2d = 22 if sector >= 221 & sector <= 223
replace sector2d = 23 if sector >= 231 & sector <= 233
replace sector2d = 24 if sector >= 241 & sector <= 247
replace sector2d = 25 if sector >= 251 & sector <= 252
replace sector2d = 26 if sector >= 261 & sector <= 268
replace sector2d = 27 if sector >= 271 & sector <= 275
replace sector2d = 28 if sector >= 281 & sector <= 287
replace sector2d = 29 if sector >= 291 & sector <= 297
replace sector2d = 30 if sector >= 300 & sector <= 300
replace sector2d = 31 if sector >= 311 & sector <= 316
replace sector2d = 32 if sector >= 321 & sector <= 323
replace sector2d = 33 if sector >= 331 & sector <= 335
replace sector2d = 34 if sector >= 341 & sector <= 343
replace sector2d = 35 if sector >= 351 & sector <= 355
replace sector2d = 36 if sector >= 361 & sector <= 366
replace sector2d = 37 if sector >= 371 & sector <= 372
replace sector2d = 40 if sector >= 401 & sector <= 403
replace sector2d = 41 if sector >= 410 & sector <= 410
replace sector2d = 45 if sector >= 451 & sector <= 455
replace sector2d = 50 if sector >= 501 & sector <= 505
replace sector2d = 51 if sector >= 511 & sector <= 517
replace sector2d = 52 if sector >= 521 & sector <= 527
replace sector2d = 55 if sector >= 551 & sector <= 555
replace sector2d = 60 if sector >= 601 & sector <= 603
replace sector2d = 61 if sector >= 611 & sector <= 612
replace sector2d = 62 if sector >= 621 & sector <= 623
replace sector2d = 63 if sector >= 631 & sector <= 634
replace sector2d = 64 if sector >= 641 & sector <= 642
replace sector2d = 65 if sector >= 651 & sector <= 652
replace sector2d = 66 if sector >= 660 & sector <= 660
replace sector2d = 67 if sector >= 671 & sector <= 672
replace sector2d = 70 if sector >= 701 & sector <= 703
replace sector2d = 71 if sector >= 711 & sector <= 714
replace sector2d = 72 if sector >= 721 & sector <= 726
replace sector2d = 73 if sector >= 731 & sector <= 732
replace sector2d = 74 if sector >= 741 & sector <= 748
replace sector2d = 75 if sector >= 751 & sector <= 753
replace sector2d = 80 if sector >= 801 & sector <= 804
replace sector2d = 85 if sector >= 851 & sector <= 853
replace sector2d = 90 if sector >= 900 & sector <= 900
replace sector2d = 91 if sector >= 911 & sector <= 913
replace sector2d = 92 if sector >= 921 & sector <= 927
replace sector2d = 93 if sector >= 930 & sector <= 930
replace sector2d = 95 if sector >= 950 & sector <= 950
replace sector2d = 99 if sector >= 990 & sector <= 990
xi i.sector2d, noomit
renpfix _I
rename sector sector3d
* Migration dummies
* Indicator for migrant arriving in urban area current month
gen migrant_arrive = 0
sort person_id date
replace migrant_arrive = 1 if ua_id != ua_id[_n - 1] & person_id == person_id[_n - 1]
* Indicator for migrant departing from urban area following month
gen migrant_depart = 0
sort person_id date
replace migrant_depart = 1 if ua_id != ua_id[_n + 1] & person_id == person_id[_n + 1]
* Firm identifiers
rename firm_id_sec estab_id
rename firm_id_tax firm_id
* Save panel
compress
save "../../output/mcvl_panel", replace
erase "../../tmp/mcvl_tax.dta"
rmdir "../../tmp/"
